import random

from controllers.ControllerTank import ControllerTank
from models.Game import Game
from models.GameObject import GameObject
from models.enums.EnumGameObjectType import EnumGameObjectType


class ControllerGame:

    @staticmethod
    def new_game():
        game = Game()

        for x in range(game.map_size[0]):
            for y in range(game.map_size[1]):

                # randomly choose map tile type
                game_object_options = [EnumGameObjectType.NotSet] * 20 + [
                    EnumGameObjectType.Forest,
                    EnumGameObjectType.Water,
                    EnumGameObjectType.Brick,
                    EnumGameObjectType.Steel
                ]
                game_object_type = random.choice(game_object_options)

                if x == int(game.map_size[0] / 2) and y == game.map_size[1] - 1:
                    game_object_type = EnumGameObjectType.Player

                if game_object_type != EnumGameObjectType.NotSet:
                    game_object = GameObject(
                        position=[x, y],
                        game_object_type=game_object_type,
                    )
                    game.game_objects.append(game_object)

                    game_object.animation_frame_duration = random.randint(0, int(game_object.animation_frame_duration_max))
                    game_object.animation_frame_max = 1
                    if game_object_type in [EnumGameObjectType.Water, EnumGameObjectType.Player]:
                        game_object.animation_frame_max = 2
                        game_object.animation_frame_duration_max = 500
                        if game_object_type != EnumGameObjectType.Player:
                            game_object.animation_is_animating = True
                        else:
                            game_object.animation_frame_duration_max = 200
        return game

    @staticmethod
    def update(game: Game, delta_time: float):
        for game_object in game.game_objects:
            if game_object.game_object_type == EnumGameObjectType.Player:
                ControllerTank.update(game_object, delta_time)

            if game_object.animation_is_animating:
                game_object.animation_frame_duration += delta_time
                if game_object.animation_frame_duration >= game_object.animation_frame_duration_max:
                    game_object.animation_frame_duration = 0;
                    game_object.animation_frame += 1
                    if game_object.animation_frame >= game_object.animation_frame_max:
                        game_object.animation_frame = 0

