import time
from typing import List

import pygame
from pygame import Surface

from controllers.ControllerGame import ControllerGame
from controllers.ControllerTank import ControllerTank
from models.enums.EnumGameObjectDirection import EnumGameObjectDirection
from models.enums.EnumGameObjectType import EnumGameObjectType
from views.components.ComponentGameObject import ComponentGameObject, sprite_width
from views.components.ComponentTank import ComponentTank
from views.components.base.ComponentBase import ComponentBase
from views.components.ui.ComponentButton import ComponentButton
from views.windows.WindowMain import WindowMain


class WindowMenu:
    def __init__(self):
        super().__init__()

        self.screen = pygame.display.set_mode(
            (500, 500)
        )
        self.is_window_visible = True
        self.ui_components: List[ComponentBase] = []

        self.ui_components.append(
            ComponentButton(
                rect=pygame.Rect(100, 100, 100, 100),
                text="Start",
            )
        )

        self.window_main = WindowMain()

    def show(self):
        # main game loop
        time_last = pygame.time.get_ticks()
        while self.is_window_visible:
            # get delta seconds
            time_current = pygame.time.get_ticks()
            delta_milisec = time_current - time_last
            time_last = time_current

            # update
            self.update(delta_milisec)

            # draw
            self.render()

            # update display
            pygame.display.flip()
            time.sleep(0.1)

    def update(self, delta_milisec):
        for ui_components in self.ui_components:
            ui_components.update(delta_milisec)

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                self.is_window_visible = False
            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    self.is_window_visible = False
            elif event.type == pygame.MOUSEMOTION:
                for ui_components in self.ui_components:
                    ui_components.on_mouse_move(event.pos)
            elif event.type == pygame.MOUSEBUTTONDOWN:
                for ui_components in self.ui_components:
                    ui_components.on_mouse_button_down()
            elif event.type == pygame.MOUSEBUTTONUP:
                for ui_components in self.ui_components:
                    ui_components.on_mouse_button_up()

    def render(self):
        self.screen.fill((0, 0, 0))
        for ui_components in self.ui_components:
            ui_components.render(self.screen)